Class: Google::Cloud::ApiRegistry::V1beta::ListMcpToolsResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/apiregistry/v1beta/service.rb

Overview

Message for response to listing McpTools

Instance Attribute Summary collapse

Instance Attribute Details

#mcp_tools::Array<::Google::Cloud::ApiRegistry::V1beta::McpTool>

Returns The list of McpTool.

Returns:



111
112
113
114
# File 'proto_docs/google/cloud/apiregistry/v1beta/service.rb', line 111

class ListMcpToolsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#next_page_token::String

Returns A token identifying a page of results the server should return.

Returns:

  • (::String)

    A token identifying a page of results the server should return.



111
112
113
114
# File 'proto_docs/google/cloud/apiregistry/v1beta/service.rb', line 111

class ListMcpToolsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#unreachable::Array<::String>

Returns Locations that could not be reached.

Returns:

  • (::Array<::String>)

    Locations that could not be reached.



111
112
113
114
# File 'proto_docs/google/cloud/apiregistry/v1beta/service.rb', line 111

class ListMcpToolsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end