Class: Google::Cloud::ApiRegistry::V1beta::ListMcpToolsResponse
- Inherits:
-
Object
- Object
- Google::Cloud::ApiRegistry::V1beta::ListMcpToolsResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/apiregistry/v1beta/service.rb
Overview
Message for response to listing McpTools
Instance Attribute Summary collapse
-
#mcp_tools ⇒ ::Array<::Google::Cloud::ApiRegistry::V1beta::McpTool>
The list of McpTool.
-
#next_page_token ⇒ ::String
A token identifying a page of results the server should return.
-
#unreachable ⇒ ::Array<::String>
Locations that could not be reached.
Instance Attribute Details
#mcp_tools ⇒ ::Array<::Google::Cloud::ApiRegistry::V1beta::McpTool>
Returns The list of McpTool.
111 112 113 114 |
# File 'proto_docs/google/cloud/apiregistry/v1beta/service.rb', line 111 class ListMcpToolsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#next_page_token ⇒ ::String
Returns A token identifying a page of results the server should return.
111 112 113 114 |
# File 'proto_docs/google/cloud/apiregistry/v1beta/service.rb', line 111 class ListMcpToolsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#unreachable ⇒ ::Array<::String>
Returns Locations that could not be reached.
111 112 113 114 |
# File 'proto_docs/google/cloud/apiregistry/v1beta/service.rb', line 111 class ListMcpToolsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |