Class: Google::Cloud::ApiRegistry::V1beta::McpServer
- Inherits:
-
Object
- Object
- Google::Cloud::ApiRegistry::V1beta::McpServer
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/apiregistry/v1beta/resources.rb
Overview
Represents an MCP Server. MCP Servers act as endpoints that expose a collection of tools that can be invoked by agents.
Instance Attribute Summary collapse
-
#capabilities ⇒ ::Google::Protobuf::Struct
The capabilities that a server may support.
-
#description ⇒ ::String
Optional.
-
#display_name ⇒ ::String
Optional.
-
#name ⇒ ::String
Identifier.
-
#state ⇒ ::Google::Cloud::ApiRegistry::V1beta::State
readonly
Output only.
-
#urls ⇒ ::Array<::String>
The base URL of the MCP server.
Instance Attribute Details
#capabilities ⇒ ::Google::Protobuf::Struct
Returns The capabilities that a server may support. Known capabilities defined in https://modelcontextprotocol.io/specification/2025-06-18/schema#servercapabilities and additional capabilities defined by the servers.
53 54 55 56 |
# File 'proto_docs/google/cloud/apiregistry/v1beta/resources.rb', line 53 class McpServer include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#description ⇒ ::String
Returns Optional. A human-readable description of the MCP Server's functionality.
53 54 55 56 |
# File 'proto_docs/google/cloud/apiregistry/v1beta/resources.rb', line 53 class McpServer include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#display_name ⇒ ::String
Returns Optional. A human readable name for the MCP server.
53 54 55 56 |
# File 'proto_docs/google/cloud/apiregistry/v1beta/resources.rb', line 53 class McpServer include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String
Returns Identifier. The resource name of the MCP Server.
Format:
projects/{project}/locations/{location}/mcpServers/{mcp_server}.
Example:
projects/12345/locations/us-central1/mcpServers/google:bigquery.googleapis.com:mcp
for 1p
projects/12345/locations/us-central1/mcpServers/apphub:starbucks for
2p.
53 54 55 56 |
# File 'proto_docs/google/cloud/apiregistry/v1beta/resources.rb', line 53 class McpServer include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#state ⇒ ::Google::Cloud::ApiRegistry::V1beta::State (readonly)
Returns Output only. The state of the MCP Server.
53 54 55 56 |
# File 'proto_docs/google/cloud/apiregistry/v1beta/resources.rb', line 53 class McpServer include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#urls ⇒ ::Array<::String>
Returns The base URL of the MCP server. Example: [geolocation.googleapis.com/mcp].
53 54 55 56 |
# File 'proto_docs/google/cloud/apiregistry/v1beta/resources.rb', line 53 class McpServer include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |