Class: Google::Cloud::ApiRegistry::V1beta::McpTool
- Inherits:
-
Object
- Object
- Google::Cloud::ApiRegistry::V1beta::McpTool
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/apiregistry/v1beta/resources.rb
Overview
Message describing McpTool object
Instance Attribute Summary collapse
-
#annotations ⇒ ::Google::Protobuf::Struct
Optional key-value object that allows developers to provide additional information regarding tool properties, behavior, and usage best practices.
-
#description ⇒ ::String
A human-readable description of the tool's functionality.
-
#display_name ⇒ ::String
Optional.
-
#input_schema ⇒ ::Google::Protobuf::Struct
A JSON Schema object defining the expected parameters for invoking the tool.
-
#mcp_server_urls ⇒ ::Array<::String>
Automatically populated reference to MCP Server.
-
#name ⇒ ::String
Identifier.
-
#output_schema ⇒ ::Google::Protobuf::Struct
Optional.
Instance Attribute Details
#annotations ⇒ ::Google::Protobuf::Struct
Returns Optional key-value object that allows developers to provide additional information regarding tool properties, behavior, and usage best practices. Annotations or tags to facilitate semantic search across tools ("semantic tags") are not in the MVP scope. When implemented, the first set of supported annotations will likely be the standard, predefined annotations from the open-source MCP spec. These include:
- title: A human-readable title for the tool, useful for UI display.
- readOnlyHint: If true, indicates the tool does not modify its environment.
- destructiveHint: If true, the tool may perform destructive updates (only meaningful when readOnlyHint is false).
- idempotentHint: If true, calling the tool repeatedly with the same arguments has no additional effect (only meaningful when readOnlyHint is false).
- openWorldHint: If true, the tool may interact with an "open world" of external entities.
105 106 107 108 |
# File 'proto_docs/google/cloud/apiregistry/v1beta/resources.rb', line 105 class McpTool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#description ⇒ ::String
Returns A human-readable description of the tool's functionality.
105 106 107 108 |
# File 'proto_docs/google/cloud/apiregistry/v1beta/resources.rb', line 105 class McpTool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#display_name ⇒ ::String
Returns Optional. A human-readable name for the tool, suitable for display.
105 106 107 108 |
# File 'proto_docs/google/cloud/apiregistry/v1beta/resources.rb', line 105 class McpTool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#input_schema ⇒ ::Google::Protobuf::Struct
Returns A JSON Schema object defining the expected parameters for invoking the tool.
105 106 107 108 |
# File 'proto_docs/google/cloud/apiregistry/v1beta/resources.rb', line 105 class McpTool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#mcp_server_urls ⇒ ::Array<::String>
Returns Automatically populated reference to MCP Server. Helpful when multiple tools are requested across different MCP Servers.
105 106 107 108 |
# File 'proto_docs/google/cloud/apiregistry/v1beta/resources.rb', line 105 class McpTool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String
Returns Identifier. The resource name of the McpTool.
Format:
projects/{project}/locations/{location}/mcpServers/{mcp_server}/mcpTools/{mcp_tool}.
Example:
projects/12345/locations/us-central1/mcpServers/google:bigquery.googleapis.com:mcp/mcpTools/insert_job
for 1p
projects/12345/locations/us-central1/mcpServers/apphub:starbucks/mcpTools/order_pizza
for 2p.
105 106 107 108 |
# File 'proto_docs/google/cloud/apiregistry/v1beta/resources.rb', line 105 class McpTool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#output_schema ⇒ ::Google::Protobuf::Struct
Returns Optional. A JSON Schema object defining the expected structure of the tool's output.
105 106 107 108 |
# File 'proto_docs/google/cloud/apiregistry/v1beta/resources.rb', line 105 class McpTool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |